.. Surprise documentation master file, created by
   sphinx-quickstart on Tue Dec 29 20:08:18 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _index:

Welcome to Surprise' documentation!
===================================

`Surprise <https://surpriselib.com>`_  is an easy-to-use Python `scikit
<https://projects.scipy.org/scikits.html>`_ for recommender systems.

If you're new to `Surprise <https://surpriselib.com>`_, we invite you to take a
look at the :ref:`getting_started` guide, where you'll find a series of
tutorials illustrating all you can do with  `Surprise
<https://surpriselib.com>`_. You can also check out the :ref:`FAQ` for many
use-case example. For installation guidelines, please refer to the `project
page <https://surpriselib.com>`_.


.. toctree::
   :caption: User Guide
   :hidden:

   getting_started
   prediction_algorithms
   building_custom_algo
   notation_standards
   FAQ


.. toctree::
   :maxdepth: 2
   :caption: API Reference
   :hidden:

   prediction_algorithms_package
   model_selection
   similarities
   accuracy
   dataset
   trainset
   reader
   dump
